
--============================================================================--
-- Local functions
--============================================================================--

---
-- Retrieves guild note for the character with a given GUID. This function only works if GuildRoster() has
-- been invoked and the GUILD_ROSTER_UPDATE event has subsequently fired.
-- @param characterGuid (string) GUID of the character
-- @return (string) The guild note set for the specified character
local function GetGuildNote(characterGuid)

	-- Get number of guild members
	local numGuildMembers = GetNumGuildMembers();

	-- Check each guild roster index for matching player
	for i=1,numGuildMembers do

		-- Get guild roster info for index
		local fullName, _, _, _, class, _, note = GetGuildRosterInfo(i);

		-- Get author name and realm
		local _, _, _, _, _, _, name, realm = pcall(GetPlayerInfoByGUID, characterGuid);

		-- If no realm returned, use player's realm
		if (not realm or realm == "") then
			_, realm = UnitFullName("PLAYER");
		end

		-- If current guild member matches the character, return the guild note 
		if (name and realm) then
			local nameAndRealm = name.."-"..gsub(realm,"[%s%-]","");
			if (fullName == nameAndRealm) then
				return note;
			end
		end
	end
end



--============================================================================--
-- Initialization
--============================================================================--

-- Load AceHook
local aceHook = LibStub("AceHook-3.0");

-- Initialize guild roster data
GuildRoster();


-- Hook GetColoredName in order to add player note
aceHook:RawHook("GetColoredName", function (event, arg1, arg2, arg3, arg4, arg5, arg6, arg7, arg8, arg9, arg10, arg11, arg12)

	-- Get guild note
	local note = GetGuildNote(arg12);

	-- Invoke original function to process 
	local coloredName = aceHook.hooks.GetColoredName(event, arg1, arg2, arg3, arg4, arg5, arg6, arg7, arg8, arg9, arg10, arg11, arg12);
	
	-- Add guild note (if found) and return
	return note and note ~= "" and (coloredName .. "] [" .. note) or coloredName;
end, true);
